| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Graphics.UI.GIGtkStrut
Synopsis
- defaultStrutConfig :: StrutConfig
- data StrutPosition
- data StrutSize
- data StrutAlignment
- data StrutConfig = StrutConfig {}
- buildStrutWindow :: (MonadFail m, MonadIO m) => StrutConfig -> m Window
- setupStrutWindow :: (MonadFail m, MonadIO m) => StrutConfig -> Window -> m ()
Documentation
data StrutPosition Source #
Instances
| Read StrutPosition Source # | |
Defined in Graphics.UI.GIGtkStrut Methods readsPrec :: Int -> ReadS StrutPosition # readList :: ReadS [StrutPosition] # | |
| Show StrutPosition Source # | |
Defined in Graphics.UI.GIGtkStrut Methods showsPrec :: Int -> StrutPosition -> ShowS # show :: StrutPosition -> String # showList :: [StrutPosition] -> ShowS # | |
| Eq StrutPosition Source # | |
Defined in Graphics.UI.GIGtkStrut Methods (==) :: StrutPosition -> StrutPosition -> Bool # (/=) :: StrutPosition -> StrutPosition -> Bool # | |
Constructors
| ExactSize Int32 | |
| ScreenRatio Rational |
data StrutAlignment Source #
Instances
| Read StrutAlignment Source # | |
Defined in Graphics.UI.GIGtkStrut Methods readsPrec :: Int -> ReadS StrutAlignment # readList :: ReadS [StrutAlignment] # | |
| Show StrutAlignment Source # | |
Defined in Graphics.UI.GIGtkStrut Methods showsPrec :: Int -> StrutAlignment -> ShowS # show :: StrutAlignment -> String # showList :: [StrutAlignment] -> ShowS # | |
| Eq StrutAlignment Source # | |
Defined in Graphics.UI.GIGtkStrut Methods (==) :: StrutAlignment -> StrutAlignment -> Bool # (/=) :: StrutAlignment -> StrutAlignment -> Bool # | |
data StrutConfig Source #
Constructors
| StrutConfig | |
Fields | |
Instances
| Default StrutConfig Source # | |
Defined in Graphics.UI.GIGtkStrut Methods def :: StrutConfig # | |
| Show StrutConfig Source # | |
Defined in Graphics.UI.GIGtkStrut Methods showsPrec :: Int -> StrutConfig -> ShowS # show :: StrutConfig -> String # showList :: [StrutConfig] -> ShowS # | |
| Eq StrutConfig Source # | |
Defined in Graphics.UI.GIGtkStrut | |
buildStrutWindow :: (MonadFail m, MonadIO m) => StrutConfig -> m Window Source #
Build a strut window to the specifications provided by the StrutConfig
argument.
setupStrutWindow :: (MonadFail m, MonadIO m) => StrutConfig -> Window -> m () Source #
Configure the provided Window so that it has the properties specified
by the StrutConfig argument.